package com.shenghuoquan.business

import android.app.Activity
import android.content.Context
import android.content.res.Configuration
import android.os.Bundle
import com.orhanobut.hawk.Hawk
import com.scwang.smart.refresh.footer.ClassicsFooter
import com.scwang.smart.refresh.header.ClassicsHeader
import com.scwang.smart.refresh.layout.SmartRefreshLayout
import com.scwang.smart.refresh.layout.constant.SpinnerStyle
import com.yidian.common.AppConfig
import com.yidian.common.YdBaseApplication
import com.yidian.common.http.ApiSaveCookiesInterceptor
import com.yidian.common.http.ApiSetCookiesInterceptor
import com.yidian.common.services.AppUpgradeService
import com.yidian.common.services.ImageService
import com.yidian.common.services.XEventService
import com.yidian.common.services.XPageService
import com.yidian.common.services.http.MBHttpReqService
import com.yidian.common.utils.UMConfigUtils
import com.yidian.commonutil.CommonUtilLifecycleModule
import com.yidian.framework.mobile.insight.config.ServerUrlConfig
import com.yidian.framework.mobile.insight.config.XDiamondProvide
import com.yidian.framework.mobile.insight.manage.XInsight
import com.yidian.framework.mobile.insight.manage.XInsightConfig
import com.yidian.framework.mobile.xdiamond.SecretUtil
import com.yidian.http.ServiceFactory
import com.yidian.news.util.ProcessUtil
import com.yidian.xarc.xbase.utils.XLogger
import com.yidian.xarc.xbrid.*
import com.yidian.xpage.XPageManager
import com.yidian.yac.core.core.YacAppSpec
import com.yidian.yac.core.zap.Zap
import com.yidian.yac.core.zap.ZapTicket
import com.yidian.yac.ftdevicefinger.core.FtDeviceFingerManager
import com.yidian.yac.pm.appupdate.PmUpdateApp
import com.yidian.yac.pm.appupdate.YDAppUpdateManager
import org.json.JSONObject
import timber.log.Timber


@YacAppSpec
class YdSubwayApplication : YdBaseApplication() {

  override fun onCreate() {
    super.onCreate()
    if (ProcessUtil.isMainProcess(this)) {
      Timber.tag("启动").e("onCreate 开始执行")
      context = this
      // 先初始化日志防止调用时报初始化异常
      if (BuildConfig.DEBUG) {
        Timber.plant(Timber.DebugTree())
      }
      UMConfigUtils.init(this)
      FtDeviceFingerManager.init(this)
      initCommonUtils()
      Zap.init(this) {}
      XPageManager.init(this)
      initXBridManager()
      loadService()
      registerActivityLifecycleCallbacks(activityLifecycle)
      // 初始化磐石SDK
      SecretUtil.init(BuildConfig.IS_ENCRYPT_DEBUG_KEY, BuildConfig.DEBUG)
      // 初始化App升级
      initAppUpgrade()
      initSmartRefreshLayout()
      // 初始化慧眼
      initXInsight()
      Timber.tag("启动").e("onCreate 执行完成")
    }
  }

  /**
   * 设置刷新 默认的header和footer
   */
  private fun initSmartRefreshLayout() {
    //设置全局的Header构建器
    SmartRefreshLayout.setDefaultRefreshHeaderCreator { context, layout ->
      layout.setPrimaryColorsId(android.R.color.transparent)//全局设置主题颜色
      ClassicsHeader(context) //指定为经典Header，默认是 贝塞尔雷达Header
    }
    //设置全局的Footer构建器
    SmartRefreshLayout.setDefaultRefreshFooterCreator { context, layout ->
      layout.setEnableLoadMoreWhenContentNotFull(true) //内容不满一页时候启用加载更多
      val footer = ClassicsFooter(context)
      footer.setBackgroundResource(android.R.color.transparent)
      footer.setDrawableSize(20f)
      footer.spinnerStyle = SpinnerStyle.FixedBehind //设置为固定在背后模式
      footer //指定为经典Footer，默认是 BallPulseFooter
    }
  }

  override fun attachBaseContext(base: Context?) {
    super.attachBaseContext(base)
    if (ProcessUtil.isMainProcess(this)) {
      module.onBaseContextAttached(base)
    }
  }

  override fun onConfigurationChanged(newConfig: Configuration) {
    super.onConfigurationChanged(newConfig)
    if (ProcessUtil.isMainProcess(this)) {
      module.onConfigurationChanged(newConfig)
    }
  }

  private fun initCommonUtils() {
    module.onCreate()
    Hawk.init(this).build()
    initHttp()
  }

  private val module: CommonUtilLifecycleModule by lazy {
    CommonUtilLifecycleModule(
      com.yidian.xarc.xbrid.BuildConfig.DEBUG,
      this,
      ".CommonInfrastructure"
    )
  }

  private val activityLifecycle = object : ActivityLifecycleCallbacks {

    override fun onActivityCreated(activity: Activity, savedInstanceState: Bundle?) {
      activityList.add(activity)
    }

    override fun onActivityStarted(activity: Activity) {

    }

    override fun onActivityResumed(activity: Activity) {

    }

    override fun onActivityPaused(activity: Activity) {

    }

    override fun onActivityStopped(activity: Activity) {

    }

    override fun onActivitySaveInstanceState(activity: Activity, outState: Bundle) {

    }

    override fun onActivityDestroyed(activity: Activity) {
      activityList.remove(activity)
    }

  }

  private fun initHttp() {
//        val header = HashMap<String, String>()
//        header["Content-Type"] = "application/json"
//        header["charset"] = "UTF-8"
//        ServiceFactory.getInstance().addInterceptor(HttpInterceptor(header))
//        ServiceFactory.getInstance().init(true, URLs.BASE_URL, 10, 10)
    ServiceFactory.getInstance().init(true, BuildConfig.API_URL, 10, 10)
    ServiceFactory.getInstance().addInterceptor(ApiSaveCookiesInterceptor())
    ServiceFactory.getInstance().addInterceptor(ApiSetCookiesInterceptor())

  }

  /**
   * 初始化XBrid
   *
   * 注意：
   * 1.如果有多个xbrid资源时，请分别进行注册，区分assetRoot名称，否则打包后出现文件丢失加载失败
   * 2.更新assert文件后不生效，可以卸载重新安装
   */
  private fun initXBridManager() {
    XBridManager.init(
      XBridApp(applicationContext) {
        online = BuildConfig.IS_UPGRADE_ONLINE // 线上、线下
        assetRoot = "www/src"//对应assets目录下存放xbrid资源对应的目录名
        appId = applicationContext.packageName //当前应用包名
        platformId = AppConfig.TowerProXBridUpgradePlatformId //需要去平台申请
        appVersion = AppConfig.cv//当前应用版本号
        deviceFinger = FtDeviceFingerManager.getDeviceFinger()//设备指纹
        androidChannel = AppConfig.distribution//对应渠道名
      }, 20//webview缓存池数量，默认不缓存
    )

    XBridManager.registerServiceInvoker(object : OnServiceInvoke {
      override fun onCall(
        identifier: String, // the identifier assigned when webview created
        xWebView: XWebView, // webivew 加载的 js 发起的服务调用请求
        request: Request, // 具体的服务请求参数，分为 name 和 params 两个部分
        response: Response // 业务方需要借助 response 来回应服务调用结果
      ) {
        val data = request.params as JSONObject
        // JS调用Native传递的数据
        Timber.tag("xbrid").e("服务名:%s", request.name)
        Timber.tag("xbrid").e("JS传递参数:%s", data)

        val action = data.optString("action")
        val params = data.optJSONObject("params")
        val options = data.optJSONObject("options")

        // 发送JS传递的数据到Service,并监听服务返回的结果回传JS
        ZapTicket(request.name).withAction(action).withServiceParams(params).withServiceOptions(options).withIdentifier(identifier)
          .onResult { result ->
            Timber.tag("xbrid").e("回传JS的结果码： ${result.code}   +  结果信息： ${result.result}")
            response.result(result.code, result.result ?: "", "")
          }.onLost { result ->
            Timber.tag("xbrid").e("回传JS的错误码： ${result.code}   +  错误信息： ${result.mesg}")
            response.result(result.code, "", result.mesg)
          }.ship()
      }
    })

    XBridManager.registerXPageInvoker(object : OnXPageInvoke {
      override fun onCall(identifier: String, xWebView: XWebView, request: XPageRequest) {
        val params = mutableMapOf<String, Any>()
        (request.params as JSONObject).let { reParams ->
          reParams.keys().forEach {
            params[it] = reParams[it]
          }
        }
        when (request.action) {
          "push" -> XPageManager.push(request.name, params)
          "pop" -> XPageManager.pop(params)
          "popTo" -> XPageManager.popTo(request.name, params)
          "popToRoot" -> XPageManager.popToRoot(params)
        }
      }
    })
  }

  private fun loadService() {
    Zap.addService(XPageService.SERVICE_NAME, XPageService())
    Zap.addService(XEventService.SERVICE_NAME, XEventService())
    Zap.addService(AppUpgradeService.SERVICE_NAME, AppUpgradeService())
    Zap.addService(MBHttpReqService.SERVICE_NAME, MBHttpReqService())
    Zap.addService(ImageService.SERVICE_NAME, ImageService())
  }

  /**
   * App升级
   */
  private fun initAppUpgrade() {
    val logger = XLogger("appUpgrade")
    logger.debugOn(BuildConfig.DEBUG)
    YDAppUpdateManager.init(PmUpdateApp(this) {
      online = BuildConfig.IS_UPGRADE_ONLINE // 线上true、线下false
      platformId = AppConfig.TowerProAppUpgradePlatformId // 平台Id
      platform = AppConfig.TowerProPlatform // ios/Android
      appId = packageName // 应用包名
      appVersion = AppConfig.cv // 客户端版本号
      deviceFinger = FtDeviceFingerManager.getDeviceFinger() // 设备指纹
      androidChannel = AppConfig.distribution // 渠道
      this.logger = logger.subLogger("appUpgrade")
    })
  }

  /**
   * 慧眼
   */
  private fun initXInsight() {
    val config = XInsightConfig()
    config.cv = AppConfig.cv
    config.device_finger = FtDeviceFingerManager.getDeviceFinger()
    config.distribution = AppConfig.distribution
    config.isEncryption = AppConfig.IS_ENCRYPT
    config.version = AppConfig.version
    config.serverUrlConfig = ServerUrlConfig.DEV_SERVER_URL
    val provide = object : XDiamondProvide {
      override fun sign(str: String?): String? {
        if (str == null) return null
        return SecretUtil.sign(str)
      }

      override fun rsaEncrypt(str: String?): String? {
        if (str == null) return null
        return SecretUtil.rsaEncrypt(str)
      }

      override fun rsaDecrypt(str: String?): String? {
        if (str == null) return null
        return SecretUtil.rsaDecrypt(str)
      }

      override fun aesEncrypt(str: String?): String? {
        if (str == null) return null
        return SecretUtil.aesEncrypt(str)
      }

      override fun aesDecrypt(str: String?): String? {
        if (str == null) return null
        return SecretUtil.aesDecrypt(str)
      }

      override fun verifySign(src: String?, sign: String?): Boolean {
        if (src == null || sign == null) return false
        return SecretUtil.verifySign(src, sign)
      }

    }
    XInsight.init(this, AppConfig.appid, BuildConfig.DEBUG, config, provide)
  }

}
